( cd usr/bin ; rm -rf tclsh )
( cd usr/bin ; ln -sf tclsh7.5 tclsh )
( cd usr/lib ; rm -rf libtcl.so )
( cd usr/lib ; ln -sf libtcl.so.1 libtcl.so )
( cd usr/lib ; rm -rf libtcl.so.1 )
( cd usr/lib ; ln -sf libtcl.so.1.7.5 libtcl.so.1 )
( cd usr/man/man3 ; rm -rf Tcl_AddErrorInfo.3.gz )
( cd usr/man/man3 ; ln -sf AddErrInfo.3.gz Tcl_AddErrorInfo.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AllowExceptions.3.gz )
( cd usr/man/man3 ; ln -sf AllowExc.3.gz Tcl_AllowExceptions.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AppInit.3.gz )
( cd usr/man/man3 ; ln -sf AppInit.3.gz Tcl_AppInit.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AppendElement.3.gz )
( cd usr/man/man3 ; ln -sf SetResult.3.gz Tcl_AppendElement.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AppendResult.3.gz )
( cd usr/man/man3 ; ln -sf SetResult.3.gz Tcl_AppendResult.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AsyncCreate.3.gz )
( cd usr/man/man3 ; ln -sf Async.3.gz Tcl_AsyncCreate.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AsyncDelete.3.gz )
( cd usr/man/man3 ; ln -sf Async.3.gz Tcl_AsyncDelete.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AsyncInvoke.3.gz )
( cd usr/man/man3 ; ln -sf Async.3.gz Tcl_AsyncInvoke.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AsyncMark.3.gz )
( cd usr/man/man3 ; ln -sf Async.3.gz Tcl_AsyncMark.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_BackgroundError.3.gz )
( cd usr/man/man3 ; ln -sf BackgdErr.3.gz Tcl_BackgroundError.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Backslash.3.gz )
( cd usr/man/man3 ; ln -sf Backslash.3.gz Tcl_Backslash.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CallWhenDeleted.3.gz )
( cd usr/man/man3 ; ln -sf CallDel.3.gz Tcl_CallWhenDeleted.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CancelIdleCall.3.gz )
( cd usr/man/man3 ; ln -sf DoWhenIdle.3.gz Tcl_CancelIdleCall.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Close.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_Close.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CommandComplete.3.gz )
( cd usr/man/man3 ; ln -sf CmdCmplt.3.gz Tcl_CommandComplete.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Concat.3.gz )
( cd usr/man/man3 ; ln -sf Concat.3.gz Tcl_Concat.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ConvertElement.3.gz )
( cd usr/man/man3 ; ln -sf SplitList.3.gz Tcl_ConvertElement.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateAlias.3.gz )
( cd usr/man/man3 ; ln -sf CrtSlave.3.gz Tcl_CreateAlias.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateChannel.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_CreateChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateChannelHandler.3.gz )
( cd usr/man/man3 ; ln -sf CrtChnlHdlr.3.gz Tcl_CreateChannelHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateCloseHandler.3.gz )
( cd usr/man/man3 ; ln -sf CrtCloseHdlr.3.gz Tcl_CreateCloseHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateCommand.3.gz )
( cd usr/man/man3 ; ln -sf CrtCommand.3.gz Tcl_CreateCommand.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateEventSource.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_CreateEventSource.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateExitHandler.3.gz )
( cd usr/man/man3 ; ln -sf Exit.3.gz Tcl_CreateExitHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateFileHandler.3.gz )
( cd usr/man/man3 ; ln -sf CrtFileHdlr.3.gz Tcl_CreateFileHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateSlave.3.gz )
( cd usr/man/man3 ; ln -sf CrtSlave.3.gz Tcl_CreateSlave.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateHashEntry.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_CreateHashEntry.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateInterp.3.gz )
( cd usr/man/man3 ; ln -sf CrtInterp.3.gz Tcl_CreateInterp.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateMathFunc.3.gz )
( cd usr/man/man3 ; ln -sf CrtMathFnc.3.gz Tcl_CreateMathFunc.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateModalTimeout.3.gz )
( cd usr/man/man3 ; ln -sf CrtModalTmt.3.gz Tcl_CreateModalTimeout.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateTimerHandler.3.gz )
( cd usr/man/man3 ; ln -sf CrtTimerHdlr.3.gz Tcl_CreateTimerHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateTrace.3.gz )
( cd usr/man/man3 ; ln -sf CrtTrace.3.gz Tcl_CreateTrace.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringAppend.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringAppend.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringAppendElement.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringAppendElement.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringEndSublist.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringEndSublist.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringFree.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringFree.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringGetResult.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringGetResult.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringInit.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringInit.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringLength.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringLength.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringResult.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringResult.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringSetLength.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringSetLength.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringStartSublist.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringStartSublist.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringValue.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringValue.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteAssocData.3.gz )
( cd usr/man/man3 ; ln -sf AssocData.3.gz Tcl_DeleteAssocData.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteChannelHandler.3.gz )
( cd usr/man/man3 ; ln -sf CrtChnlHdlr.3.gz Tcl_DeleteChannelHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteCloseHandler.3.gz )
( cd usr/man/man3 ; ln -sf CrtCloseHdlr.3.gz Tcl_DeleteCloseHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteCommand.3.gz )
( cd usr/man/man3 ; ln -sf CrtCommand.3.gz Tcl_DeleteCommand.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteEventSource.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_DeleteEventSource.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteExitHandler.3.gz )
( cd usr/man/man3 ; ln -sf Exit.3.gz Tcl_DeleteExitHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteFileHandler.3.gz )
( cd usr/man/man3 ; ln -sf CrtFileHdlr.3.gz Tcl_DeleteFileHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteHashEntry.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_DeleteHashEntry.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteHashTable.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_DeleteHashTable.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteInterp.3.gz )
( cd usr/man/man3 ; ln -sf CrtInterp.3.gz Tcl_DeleteInterp.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteModalTimeout.3.gz )
( cd usr/man/man3 ; ln -sf CrtModalTmt.3.gz Tcl_DeleteModalTimeout.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteTimerHandler.3.gz )
( cd usr/man/man3 ; ln -sf CrtTimerHdlr.3.gz Tcl_DeleteTimerHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteTrace.3.gz )
( cd usr/man/man3 ; ln -sf CrtTrace.3.gz Tcl_DeleteTrace.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DetachPids.3.gz )
( cd usr/man/man3 ; ln -sf DetachPids.3.gz Tcl_DetachPids.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DoOneEvent.3.gz )
( cd usr/man/man3 ; ln -sf DoOneEvent.3.gz Tcl_DoOneEvent.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DoWhenIdle.3.gz )
( cd usr/man/man3 ; ln -sf DoWhenIdle.3.gz Tcl_DoWhenIdle.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DontCallWhenDeleted.3.gz )
( cd usr/man/man3 ; ln -sf CallDel.3.gz Tcl_DontCallWhenDeleted.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Eof.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_Eof.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Eval.3.gz )
( cd usr/man/man3 ; ln -sf Eval.3.gz Tcl_Eval.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_EvalFile.3.gz )
( cd usr/man/man3 ; ln -sf Eval.3.gz Tcl_EvalFile.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_EventuallyFree.3.gz )
( cd usr/man/man3 ; ln -sf Preserve.3.gz Tcl_EventuallyFree.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Exit.3.gz )
( cd usr/man/man3 ; ln -sf Exit.3.gz Tcl_Exit.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ExprBoolean.3.gz )
( cd usr/man/man3 ; ln -sf ExprLong.3.gz Tcl_ExprBoolean.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ExprDouble.3.gz )
( cd usr/man/man3 ; ln -sf ExprLong.3.gz Tcl_ExprDouble.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ExprLong.3.gz )
( cd usr/man/man3 ; ln -sf ExprLong.3.gz Tcl_ExprLong.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ExprString.3.gz )
( cd usr/man/man3 ; ln -sf ExprLong.3.gz Tcl_ExprString.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FileReady.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_FileReady.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FindExecutable.3.gz )
( cd usr/man/man3 ; ln -sf FindExec.3.gz Tcl_FindExecutable.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FindHashEntry.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_FindHashEntry.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FirstHashEntry.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_FirstHashEntry.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Flush.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_Flush.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FreeFile.3.gz )
( cd usr/man/man3 ; ln -sf GetFile.3.gz Tcl_FreeFile.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetAlias.3.gz )
( cd usr/man/man3 ; ln -sf CrtSlave.3.gz Tcl_GetAlias.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetAliases.3.gz )
( cd usr/man/man3 ; ln -sf CrtSlave.3.gz Tcl_GetAliases.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetAssocData.3.gz )
( cd usr/man/man3 ; ln -sf AssocData.3.gz Tcl_GetAssocData.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetBoolean.3.gz )
( cd usr/man/man3 ; ln -sf GetInt.3.gz Tcl_GetBoolean.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetChannelBufferSize.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_GetChannelBufferSize.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetChannelFile.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_GetChannelFile.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetChannelInstanceData.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_GetChannelInstanceData.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetChannelName.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_GetChannelName.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetChannelOption.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_GetChannelOption.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetChannelType.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_GetChannelType.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetCommandInfo.3.gz )
( cd usr/man/man3 ; ln -sf CrtCommand.3.gz Tcl_GetCommandInfo.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetDouble.3.gz )
( cd usr/man/man3 ; ln -sf GetInt.3.gz Tcl_GetDouble.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetErrno.3.gz )
( cd usr/man/man3 ; ln -sf SetErrno.3.gz Tcl_GetErrno.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetFile.3.gz )
( cd usr/man/man3 ; ln -sf GetFile.3.gz Tcl_GetFile.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetFileInfo.3.gz )
( cd usr/man/man3 ; ln -sf GetFile.3.gz Tcl_GetFileInfo.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetHashKey.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_GetHashKey.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetHashValue.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_GetHashValue.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetInt.3.gz )
( cd usr/man/man3 ; ln -sf GetInt.3.gz Tcl_GetInt.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetMaster.3.gz )
( cd usr/man/man3 ; ln -sf CrtSlave.3.gz Tcl_GetMaster.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetOpenFile.3.gz )
( cd usr/man/man3 ; ln -sf GetOpnFl.3.gz Tcl_GetOpenFile.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetSlave.3.gz )
( cd usr/man/man3 ; ln -sf CrtSlave.3.gz Tcl_GetSlave.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetSlaves.3.gz )
( cd usr/man/man3 ; ln -sf CrtSlave.3.gz Tcl_GetSlaves.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetStdChannel.3.gz )
( cd usr/man/man3 ; ln -sf GetStdChan.3.gz Tcl_GetStdChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetVar.3.gz )
( cd usr/man/man3 ; ln -sf SetVar.3.gz Tcl_GetVar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetVar2.3.gz )
( cd usr/man/man3 ; ln -sf SetVar.3.gz Tcl_GetVar2.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Gets.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_Gets.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GlobalEval.3.gz )
( cd usr/man/man3 ; ln -sf Eval.3.gz Tcl_GlobalEval.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_HashStats.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_HashStats.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_InitHashTable.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_InitHashTable.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_InputBlocked.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_InputBlocked.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Interp.3.gz )
( cd usr/man/man3 ; ln -sf Interp.3.gz Tcl_Interp.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_InterpDeleted.3.gz )
( cd usr/man/man3 ; ln -sf CrtInterp.3.gz Tcl_InterpDeleted.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_IsSafe.3.gz )
( cd usr/man/man3 ; ln -sf CrtSlave.3.gz Tcl_IsSafe.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_LinkVar.3.gz )
( cd usr/man/man3 ; ln -sf LinkVar.3.gz Tcl_LinkVar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_MakeSafe.3.gz )
( cd usr/man/man3 ; ln -sf CrtSlave.3.gz Tcl_MakeSafe.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Merge.3.gz )
( cd usr/man/man3 ; ln -sf SplitList.3.gz Tcl_Merge.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_NextHashEntry.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_NextHashEntry.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_OpenCommandChannel.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_OpenCommandChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_OpenFileChannel.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_OpenFileChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_OpenTcpClient.3.gz )
( cd usr/man/man3 ; ln -sf OpenTcp.3.gz Tcl_OpenTcpClient.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_OpenTcpServer.3.gz )
( cd usr/man/man3 ; ln -sf OpenTcp.3.gz Tcl_OpenTcpServer.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_PkgProvide.3.gz )
( cd usr/man/man3 ; ln -sf PkgRequire.3.gz Tcl_PkgProvide.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_PkgRequire.3.gz )
( cd usr/man/man3 ; ln -sf PkgRequire.3.gz Tcl_PkgRequire.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_PosixError.3.gz )
( cd usr/man/man3 ; ln -sf AddErrInfo.3.gz Tcl_PosixError.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Preserve.3.gz )
( cd usr/man/man3 ; ln -sf Preserve.3.gz Tcl_Preserve.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_PrintDouble.3.gz )
( cd usr/man/man3 ; ln -sf PrintDbl.3.gz Tcl_PrintDouble.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_QueueEvent.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_QueueEvent.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Read.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_Read.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ReapDetachedProcs.3.gz )
( cd usr/man/man3 ; ln -sf DetachPids.3.gz Tcl_ReapDetachedProcs.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_RecordAndEval.3.gz )
( cd usr/man/man3 ; ln -sf RecordEval.3.gz Tcl_RecordAndEval.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_RegExpCompile.3.gz )
( cd usr/man/man3 ; ln -sf RegExp.3.gz Tcl_RegExpCompile.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_RegExpExec.3.gz )
( cd usr/man/man3 ; ln -sf RegExp.3.gz Tcl_RegExpExec.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_RegExpMatch.3.gz )
( cd usr/man/man3 ; ln -sf RegExp.3.gz Tcl_RegExpMatch.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_RegExpRange.3.gz )
( cd usr/man/man3 ; ln -sf RegExp.3.gz Tcl_RegExpRange.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Release.3.gz )
( cd usr/man/man3 ; ln -sf Preserve.3.gz Tcl_Release.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ResetResult.3.gz )
( cd usr/man/man3 ; ln -sf SetResult.3.gz Tcl_ResetResult.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ScanElement.3.gz )
( cd usr/man/man3 ; ln -sf SplitList.3.gz Tcl_ScanElement.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Seek.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_Seek.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetAssocData.3.gz )
( cd usr/man/man3 ; ln -sf AssocData.3.gz Tcl_SetAssocData.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetChannelBufferSize.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_SetChannelBufferSize.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetChannelOption.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_SetChannelOption.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetCommandInfo.3.gz )
( cd usr/man/man3 ; ln -sf CrtCommand.3.gz Tcl_SetCommandInfo.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetDefaultTranslation.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_SetDefaultTranslation.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetErrno.3.gz )
( cd usr/man/man3 ; ln -sf SetErrno.3.gz Tcl_SetErrno.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetErrorCode.3.gz )
( cd usr/man/man3 ; ln -sf AddErrInfo.3.gz Tcl_SetErrorCode.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetHashValue.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_SetHashValue.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetMaxBlockTime.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_SetMaxBlockTime.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetRecursionLimit.3.gz )
( cd usr/man/man3 ; ln -sf SetRecLmt.3.gz Tcl_SetRecursionLimit.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetResult.3.gz )
( cd usr/man/man3 ; ln -sf SetResult.3.gz Tcl_SetResult.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetStdChannel.3.gz )
( cd usr/man/man3 ; ln -sf GetStdChan.3.gz Tcl_SetStdChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetVar.3.gz )
( cd usr/man/man3 ; ln -sf SetVar.3.gz Tcl_SetVar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetVar2.3.gz )
( cd usr/man/man3 ; ln -sf SetVar.3.gz Tcl_SetVar2.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Sleep.3.gz )
( cd usr/man/man3 ; ln -sf Sleep.3.gz Tcl_Sleep.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SplitList.3.gz )
( cd usr/man/man3 ; ln -sf SplitList.3.gz Tcl_SplitList.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_StaticPackage.3.gz )
( cd usr/man/man3 ; ln -sf StaticPkg.3.gz Tcl_StaticPackage.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_StringMatch.3.gz )
( cd usr/man/man3 ; ln -sf StrMatch.3.gz Tcl_StringMatch.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Tell.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_Tell.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_TraceVar.3.gz )
( cd usr/man/man3 ; ln -sf TraceVar.3.gz Tcl_TraceVar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_TraceVar2.3.gz )
( cd usr/man/man3 ; ln -sf TraceVar.3.gz Tcl_TraceVar2.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_TranslateFileName.3.gz )
( cd usr/man/man3 ; ln -sf Translate.3.gz Tcl_TranslateFileName.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UnlinkVar.3.gz )
( cd usr/man/man3 ; ln -sf LinkVar.3.gz Tcl_UnlinkVar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UnsetVar.3.gz )
( cd usr/man/man3 ; ln -sf SetVar.3.gz Tcl_UnsetVar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UnsetVar2.3.gz )
( cd usr/man/man3 ; ln -sf SetVar.3.gz Tcl_UnsetVar2.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UntraceVar.3.gz )
( cd usr/man/man3 ; ln -sf TraceVar.3.gz Tcl_UntraceVar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UntraceVar2.3.gz )
( cd usr/man/man3 ; ln -sf TraceVar.3.gz Tcl_UntraceVar2.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UpVar.3.gz )
( cd usr/man/man3 ; ln -sf UpVar.3.gz Tcl_UpVar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UpVar2.3.gz )
( cd usr/man/man3 ; ln -sf UpVar.3.gz Tcl_UpVar2.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UpdateLinkedVar.3.gz )
( cd usr/man/man3 ; ln -sf LinkVar.3.gz Tcl_UpdateLinkedVar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_VarEval.3.gz )
( cd usr/man/man3 ; ln -sf Eval.3.gz Tcl_VarEval.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_VarTraceInfo.3.gz )
( cd usr/man/man3 ; ln -sf TraceVar.3.gz Tcl_VarTraceInfo.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_VarTraceInfo2.3.gz )
( cd usr/man/man3 ; ln -sf TraceVar.3.gz Tcl_VarTraceInfo2.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_WaitForEvent.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_WaitForEvent.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_WatchFile.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_WatchFile.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Write.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_Write.3.gz )
( cd usr/man/mann ; rm -rf pkg_mkIndex.n.gz )
( cd usr/man/mann ; ln -sf pkgMkIndex.n.gz pkg_mkIndex.n.gz )
